.. _release-notes:

###################################
Release notes & upgrade information
###################################

Some versions of django CMS present more complex upgrade paths than others, and some **require** you
to take action. It is strongly recommended to read the release notes carefully when upgrading.

It goes without saying that you should **backup your database** before embarking on any process that
makes changes to your database.

.. toctree::
    :maxdepth: 1

    3.7.1
    3.7
    3.6
    3.5.3
    3.5.2
    3.5.1
    3.5
    3.4.4
    3.4.3
    3.4.2
    3.4.1
    3.4
    3.3
    3.2.5
    3.2.4
    3.2.3
    3.2.2
    3.2.1
    3.2
    3.1.5
    3.1.4
    3.1.3
    3.1.2
    3.1.1
    3.1
    3.0.16
    3.0.15
    3.0.14
    3.0.13
    3.0.12
    3.0.11
    3.0.10
    3.0.9
    3.0.8
    3.0.7
    3.0.6
    3.0.3
    3.0
    2.4
    2.3.4
    2.3.3
    2.3.2
    2.3
    2.2
    2.1
